#  Module.mk - Makefile for the Psion conversion utilities
#  Copyright (c) 1999  Frodo Looijaard <frodol@dds.nl>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# Note that MODULE_DIR (the directory in which this file resides) is a
# 'simply expanded variable'. That means that its value is substituted
# verbatim in the rules, until it is redefined. 
MODULE_DIR := formats

# Regrettably, even 'simply expanded variables' will not put their currently
# defined value verbatim into the command-list of rules...
FORMATSSOURCES := $(MODULE_DIR)/Application_ID_Section.psi \
                  $(MODULE_DIR)/ASCII_Codes.psi \
                  $(MODULE_DIR)/Basic_Elements.psi \
                  $(MODULE_DIR)/Basic_Structures.psi \
                  $(MODULE_DIR)/Fonts.psi \
                  $(MODULE_DIR)/Header_Section.psi \
                  $(MODULE_DIR)/Identifiers.psi \
                  $(MODULE_DIR)/Index.psi \
                  $(MODULE_DIR)/Introduction.psi \
                  $(MODULE_DIR)/Layout_Codes.psi \
                  $(MODULE_DIR)/Page_Layout_Section.psi \
                  $(MODULE_DIR)/Section_Table_Section.psi \
                  $(MODULE_DIR)/Substitutions.psi \
                  $(MODULE_DIR)/Text_Layout_Section.psi \
                  $(MODULE_DIR)/Text_Section.psi \
                  $(MODULE_DIR)/Word_File.psi \
                  $(MODULE_DIR)/Word_Status_Section.psi \
                  $(MODULE_DIR)/Word_Styles_Section.psi 
FORMATSTARGETS := $(FORMATSSOURCES:.psi=.html)
FORMATSINTERS := $(FORMATSSOURCES:.psi=.html_plain)

ifeq "$(DEBUG)" "0"
.INTERMEDIATE: $(FORMATSINTERS)
endif

FORMATSMAKEINDEX := $(MODULE_DIR)/make_target_index.sh
FORMATSGENERATE := $(MODULE_DIR)/generate_links.sh

FORMATSINDEX := $(MODULE_DIR)/html_index

$(FORMATSINDEX): $(FORMATSMAKEINDEX) $(FORMATSINTERS)
	cd $(MODULE_DIR); \
        $(notdir $(FORMATSMAKEINDEX)) $(notdir $(FORMATSINDEX).temp) \
                                      $(notdir $(FORMATSINTERS)) 
	sed 's,^\([a-zA-z_]*\)\.html_plain,\1.html,' \
            < $(FORMATSINDEX).temp > $(FORMATSINDEX) 
	rm $(FORMATSINDEX).temp
        

%.html: %.html_plain $(FORMATSGENERATE) $(FORMATSINDEX)
	$(FORMATSGENERATE) $(FORMATSINDEX) $< > $@

%.html_plain: %.psi $(PSICONV)
	$(PSICONV) $< -o $@
	
all-formats: $(FORMATSTARGETS)
all :: all-formats

clean-formats:
	$(RM) $(FORMATSTARGETS) $(FORMATSINTERS) $(FORMATSINDEX) $(FORMATSINDEX).temp
clean :: clean-formats
